==> rheolef_6.5.orig.tar.gz: rheolef-6.5/util/lib/the_clock.cc <==
///
/// This file is part of Rheolef.
///
/// Copyright (C) 2000-2009 Pierre Saramito <Pierre.Saramito@imag.fr>
///
/// Rheolef is free software; you can redistribute it and/or modify
/// it under the terms of the GNU General Public License as published by
/// the Free Software Foundation; either version 2 of the License, or
/// (at your option) any later version.
///
/// Rheolef is distributed in the hope that it will be useful,
/// but WITHOUT ANY WARRANTY; without even the implied warranty of
/// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/// GNU General Public License for more details.
///
/// You should have received a copy of the GNU General Public License
/// along with Rheolef; if not, write to the Free Software
/// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
///
/// =========================================================================
# include "rheolef/config.h"
// 
// NOTE: this version comes from the mipc source code
//

#if defined(_RHEOLEF_HAVE_GETTIMEOFDAY) || defined(_RHEOLEF_HAVE_WIERDGETTIMEOFDAY)
#include <sys/types.h>
#include <sys/time.h>
#endif
/* I don't know what the correct includes are for the other versions... */

using namespace std;
namespace rheolef {
double the_clock()
{
#if defined(_RHEOLEF_HAVE_WIERDGETTIMEOFDAY)
    /* This is for Solaris, where they decided to change the CALLING
       SEQUENCE OF gettimeofday! */
    struct timeval tp;

    gettimeofday(&tp);
    return((double) tp.tv_sec + .000001 * (double) tp.tv_usec);
#elif defined(_RHEOLEF_HAVE_GETTIMEOFDAY)
    struct timeval tp;
    struct timezone tzp;

    gettimeofday(&tp,&tzp);
    return((double) tp.tv_sec + .000001 * (double) tp.tv_usec);
#elif defined(_RHEOLEF_HAVE_BSDGETTIMEOFDAY)
    struct timeval tp;
    struct timezone tzp;

    BSDgettimeofday(&tp,&tzp);
    return((double) tp.tv_sec + .000001 * (double) tp.tv_usec);
#else
    return amicclk()*1.0e-6;
#endif
}
}// namespace rheolef

==> rheolef_6.6.orig.tar.gz: rheolef-6.6/util/lib/the_clock.cc <==
///
/// This file is part of Rheolef.
///
/// Copyright (C) 2000-2009 Pierre Saramito <Pierre.Saramito@imag.fr>
///
/// Rheolef is free software; you can redistribute it and/or modify
/// it under the terms of the GNU General Public License as published by
/// the Free Software Foundation; either version 2 of the License, or
/// (at your option) any later version.
///
/// Rheolef is distributed in the hope that it will be useful,
/// but WITHOUT ANY WARRANTY; without even the implied warranty of
/// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/// GNU General Public License for more details.
///
/// You should have received a copy of the GNU General Public License
/// along with Rheolef; if not, write to the Free Software
/// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
///
/// =========================================================================
# include "rheolef/config.h"
// 
// NOTE: this version comes from the mipc source code
//

#ifdef _RHEOLEF_HAVE_CLOCK_GETTIME
#include <time.h>
#elif defined(_RHEOLEF_HAVE_GETTIMEOFDAY) || defined(_RHEOLEF_HAVE_WIERDGETTIMEOFDAY)
#include <sys/types.h>
#include <sys/time.h>
#else
#include <ctime>
#endif

using namespace std;
namespace rheolef {
double the_clock()
{
#if defined(_RHEOLEF_HAVE_CLOCK_GETTIME)
    // high precision clock
#ifdef CLOCK_HIGHRES
#define SAMPLED_CLOCK CLOCK_HIGHRES
#else
#define SAMPLED_CLOCK CLOCK_REALTIME
#endif
    struct timespec tp;
    if (clock_gettime(SAMPLED_CLOCK, &tp) != 0) {
      return 0; // failure
    }
    return double(tp.tv_sec) + 1e-9*double(tp.tv_nsec);
#elif defined(_RHEOLEF_HAVE_WIERDGETTIMEOFDAY)
    // This is for Solaris, where they decided to change the CALLING SEQUENCE OF gettimeofday
    struct timeval tp;
    gettimeofday(&tp);
    return double(tp.tv_sec) + 1e-6*double(tp.tv_usec);
#elif defined(_RHEOLEF_HAVE_GETTIMEOFDAY)
    struct timeval tp;
    struct timezone tzp;
    gettimeofday(&tp,&tzp);
    return double(tp.tv_sec) + 1e-6*double(tp.tv_usec);
#elif defined(_RHEOLEF_HAVE_BSDGETTIMEOFDAY)
    struct timeval tp;
    struct timezone tzp;
    BSDgettimeofday(&tp,&tzp);
    return double(tp.tv_sec) + 1e-6*double(tp.tv_usec);
#else
    // fall back to low resolution time function
    time_t tp, zero = 0;
    time (&tp);
    return difftime(time(&tp), zero);
#endif
}
}// namespace rheolef
